@@ -1,10 +1,10 @@
-from fpql.bonds import get_qlfixedratebond
+from .bonds import get_qlfixedratebond
 import QuantLib as ql 
-from fpql.ql_enums import *
-from fpql.pymodels import *
-from fpql.ql_utils import *
-from fpql.ql_conventions import *
-from fpql.termstructure import *
+from .ql_enums import *
+from .pymodels import *
+from .ql_utils import *
+from .ql_conventions import *
+from .termstructure import *
 
 def sample_piecewise(value_date):
     rates, depo_setting, parrates, par_setting = sample_curveinfo()
